@@ -1,9 +1,10 @@
 package RosettaCode;
-our $VERSION = '0.0.14';
+our $VERSION = '0.0.15';
 
 use utf8;
 use MediaWiki::Bot;
 use YAML::XS;
+use Carp;
 
 use App::Cmd::Setup ();
 App::Cmd::Setup->import(-app);
@@ -141,10 +142,13 @@ sub parse_task_page {
 sub parse_description {
     my ($self, $content) = @_;
     $$content =~ s/\A\[\[File:.*\s*//;
+    $$content =~ s/\A\{\{alertbox\|.*\n\s*//;
     $$content =~ s/\A\{\{[Cc]larified-review\}\}\s*//;
     $$content =~ s/\A\{\{[Cc]larify task\}\}\s*//;
+    $$content =~ s/\A\{\{[Oo]mit from\|.*\}\}\s*//;
+    $$content =~ s/\A\[\[[Ff]ile:.*\]\]\s*//;
     $$content =~ s/\A\{\{[Ww]ikipedia[^\}]*\}\}\s*//;
-    $$content =~ s/\A\{\{[Tt]ask(?:\|([^\}]*?))?\}\}(.*?\n)(?===\{\{)//s or return;
+    $$content =~ s/\A\{\{(?:[Dd]raft\s+)?[Tt]ask(?:\|([^\}]*?))?\}\}(.*?\n)(?===\{\{)//s or return;
     my ($note, $text) = ($1, $2);
     my $meta = $note ? {note => $note} : undef;
     while ($text =~ /\A\s*(?:\{\{requires|\[\[Category:)/) {
@@ -286,6 +290,10 @@ sub build_bot {
     ROSETTACODE_API_URL =~ m!^(https?)://([^/]+)/(.*)/api.php$! or die;
     my ($protocol, $host, $path) = ($1, $2, $3);
     MediaWiki::Bot->new({
+        agent =>
+            'rosettacodedata/' . $VERSION
+            . ' (https://github.com/ingydotnet/rosettacode-pm) MediaWiki::Bot/'
+            . MediaWiki::Bot->VERSION,
         assert => 'bot',
         protocol => $protocol,
         host => $host,
@@ -328,7 +336,7 @@ sub parse_fail {
     my ($self, $task, $content) = @_;
     my $msg = "Task '$task' parse failed:\n" . substr($content, 0, 200);
     Log $msg;
-    die $msg;
+    Carp::confess $msg;
 }
 
 1;
